@@ -55,7 +55,7 @@ U61_Application application;
  */ 
 char *U61_Application::get_title()
 {
-	return "U61 by U-Foot (ufoot@ufoot.org / www.ufoot.org)";
+	return "U61 0.1.1 by U-Foot (ufoot@ufoot.org / www.ufoot.org)";
 }
 
 /*--------------------------------------------------------------------------*/
@@ -64,24 +64,11 @@ char *U61_Application::get_title()
  */
 int U61_Application::main(int /*argc*/, char** /*argv*/)
 {
-    //U61_Game *game;
-
-    //CL_System::init_display();
-    //CL_System::init_sound();
-    //CL_System::init_network();
-    
-    //game=new U61_Game();
     if (U61_Global::game.init())
     {
         U61_Global::game.run();
     }
     U61_Global::game.deinit();
-    
-    //delete game;
-        
-    //CL_System::deinit_network();
-    //CL_System::deinit_sound();
-    //CL_System::deinit_display();
 
     return 0;
 }
