@@ -44,6 +44,7 @@
 #include <string.h>
 
 #include "data.h"
+#include "const.h"
 #include "debug.h"
 #include "platform.h"
 
@@ -100,7 +101,7 @@ void U61_Data::unload()
 bool U61_Data::load1(char *name)
 {
     bool success=true;
-    char full_name[1000];
+    char full_name[U61_STRING_SIZE];
     
     /*
      * adds the install path before the name of the data file
@@ -114,14 +115,14 @@ bool U61_Data::load1(char *name)
      * creation of the resource manager, which will be
      * used to load all the sections
      */
-    cout<<"Loading data from \""<<full_name<<"\".\n";
+    //cout<<"Loading data from \""<<full_name<<"\".\n";
     manager=CL_ResourceManager::create(full_name,true);
 
     if (manager!=NULL)
     {
         if (success)
         {
-            cout<<"Loading properties\n";
+            //cout<<"Loading properties\n";
             success=success && load_properties();
         }
     }
@@ -150,37 +151,37 @@ bool U61_Data::load2()
          */
         if (success)
         {
-            cout<<"Loading fonts\n";
+            //cout<<"Loading fonts\n";
 	    success=success && load_fonts();
         }
         
         if (success)
         {
-            cout<<"Loading sounds\n";
+            //cout<<"Loading sounds\n";
 	    success=success && load_sounds();
         }
         
         if (success)
         {
-            cout<<"Loading musics\n";
+            //cout<<"Loading musics\n";
 	    success=success && load_musics();
         }
 
         if (success)
         {
-            cout<<"Loading squares\n";
+            //cout<<"Loading squares\n";
 	    success=success && load_squares();
         }
 
         if (success)
         {
-            cout<<"Loading maps\n";
+            //cout<<"Loading maps\n";
 	    success=success && load_maps();
         }
 
         if (success)
         {
-            cout<<"Loading background\n";
+            //cout<<"Loading background\n";
 	    success=success && load_back();
         }
     }
@@ -289,7 +290,7 @@ bool U61_Data::load_squares()
 {
     bool success=true;
     int type;
-    char id[1000];
+    char id[U61_STRING_SIZE];
 //    CL_Surface *temp;
 
     for (type=0; type<NB_SQUARE_TYPE; ++type)
@@ -365,7 +366,7 @@ bool U61_Data::load_maps()
     bool success=true;
     int level;
     int level_max;
-    char id[1000];
+    char id[U61_STRING_SIZE];
 
     level_max=CL_Res_Integer::load(ID_MAP_NUMBER,manager,1);
     nb_map=0;
