@@ -53,6 +53,7 @@
 #include "script.h"
 #include "global.h"
 #include "platform.h"
+#include "keychoose.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -95,6 +96,7 @@ bool U61_Game::init()
     calls_to_poll=0;
     calls_to_poll_clanlib=0;
     calls_to_poll_u61=0;
+    calls_to_poll_menu=0;
     calls_to_display=0;
     calls_to_menu=0;
     calls_to_logic=0;
@@ -111,7 +113,7 @@ bool U61_Game::init()
 
     if (success)
     {
-        cout<<"Trying video mode\n";
+        //cout<<"Trying video mode\n";
         CL_Display::set_videomode(U61_Global::data.screen_w,
                                   U61_Global::data.screen_h,16,false);
     }
@@ -120,10 +122,6 @@ bool U61_Game::init()
     {
         success=success && U61_Global::data.load2();
     }  
-    if (success)
-    {
-        success=success && U61_Global::config.load_script();
-    }  
 
     //cout<<"Setting video mode\n";
     //CL_Display::set_videomode(640,480,16,false);
@@ -153,7 +151,7 @@ void U61_Game::run()
     int done_for_this_display;
     U61_Menu *exit_menu;
 
-    state=STATE_GO;
+    state=STATE_RUN;
     
     bind_keys();
     reset_players();
@@ -165,12 +163,17 @@ void U61_Game::run()
      */
     U61_Time::reset();
     last_clanlib_time_polled=CL_System::get_time();
+    last_menu_time_polled=CL_System::get_time();
     last_u61_time_polled=U61_Time::for_event();
 
+    /*
+     * we have to set this so that the keychoose item works
+     */
+    U61_KeyChoose::register_key_map(&menu_input);
+
     /*
      * the game starts on the main menu, which has the exit menu as
      * a parent, logical, eh?
-     *
      */
     exit_menu=new U61_ExitMenu();
     current_menu=new U61_MainMenu(exit_menu);
@@ -184,7 +187,7 @@ void U61_Game::run()
     /*
      * main game loop
      */
-    while (state==STATE_GO) 
+    while (state==STATE_RUN) 
     {
         /*
          * we perform calls to the logic function, but we don't
@@ -232,9 +235,9 @@ void U61_Game::run()
 /*
  * stops the game, ie exits the main game loop, 
  */
-void U61_Game::stop()
+void U61_Game::quit()
 {
-    state=STATE_STOP;
+    state=STATE_QUIT;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -260,6 +263,18 @@ void U61_Game::poll()
         calls_to_poll_clanlib++;
 
         u61_time=U61_Time::for_event();
+        /*
+         * this test disables useless polling
+         * polling is done at a maximum rate of 30 / sec
+         */
+        if (last_menu_time_polled<clanlib_time-MENU_POLL_DELAY)
+        {
+            last_menu_time_polled=clanlib_time;   
+
+            menu_input.poll(u61_time);
+
+            calls_to_poll_menu++;     
+        }
         /*
          * this test disables useless polling
          * polling is done at a maximum rate of once per game cycle
@@ -268,7 +283,6 @@ void U61_Game::poll()
         {
             last_u61_time_polled=u61_time;   
 
-            menu_input.poll(u61_time);
             for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
             {
                 player_input[i].poll(u61_time);
@@ -345,7 +359,7 @@ void U61_Game::menu()
 
     if (next_menu==NULL)
     {
-        stop();
+        quit();
     }
     else
     {
@@ -360,17 +374,49 @@ void U61_Game::menu()
     calls_to_menu++;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * retrieves parameters from the config , which can not change during
+ * the game, such as game speeds
+ */
+void U61_Game::configure_cold()
+{
+    
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * retrieves parameters from the config , which might change during
+ * the game, such as key settings
+ */
+void U61_Game::configure_hot()
+{
+    int i;
+
+    bind_keys();
+    for (i=0;i<U61_Layout::NB_PLAYERS_LOCAL;++i)
+    {
+    } 
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * starts a local game, with only one player, without asking questions
  */
 void U61_Game::start_quick()
 {
-    cout<<"quick start\n";
-    time_reset();
-    reset_players();
-    player[0].init_local(&(player_input[0]),0);
-    layout.init_alone(player);
+    int num;
+
+    //cout<<"quick start\n";
+    if (standard_init())
+    {
+        num=get_local_player(0);
+        //cout<<"num="<<num<<"\n";
+        //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
+        player[0].init_local(&(player_input[num]),0,
+            &(U61_Global::config.player[num]));
+        layout.init_alone(&(player[0]));
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -379,11 +425,18 @@ void U61_Game::start_quick()
  */
 void U61_Game::start_local_alone()
 {
-    cout<<"local alone game started\n";
-    time_reset();
-    reset_players();
-    player[0].init_local(&(player_input[0]),0);
-    layout.init_alone(player);
+    int num;
+
+    //cout<<"local alone game started\n";
+    if (standard_init())
+    {
+        num=get_local_player(0);
+        //cout<<"num="<<num<<"\n";
+        //cout<<"name="<<U61_Global::config.player[num].name<<"\n";
+        player[0].init_local(&(player_input[num]),0,
+            &(U61_Global::config.player[num]));
+        layout.init_alone(&(player[0]));
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -392,10 +445,10 @@ void U61_Game::start_local_alone()
  */
 void U61_Game::start_local_multiplayer()
 {
-    cout<<"local multiplayer game started\n";
-    time_reset();
-    reset_players();
-    layout.reset();
+    //cout<<"local multiplayer game started\n";
+    if (standard_init())
+    {
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -404,10 +457,10 @@ void U61_Game::start_local_multiplayer()
  */
 void U61_Game::start_network_new()
 {
-    cout<<"new network game started\n";
-    time_reset();
-    reset_players();
-    layout.reset();
+    //cout<<"new network game started\n";
+    if (standard_init())
+    {
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -416,12 +469,42 @@ void U61_Game::start_network_new()
  */
 void U61_Game::start_network_join()
 {
-    cout<<"joining network game\n";
-    time_reset();
+    //cout<<"joining network game\n";
+    if (standard_init())
+    {
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * stops the current game, if existing. it does not quit u61.
+ */
+void U61_Game::stop()
+{
     reset_players();
     layout.reset();
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * standard initialization before starting a new game
+ */
+bool U61_Game::standard_init()
+{
+    bool ok=true;
+
+    configure_cold();
+    configure_hot();
+
+    time_reset();
+
+    stop();
+
+    ok=ok && U61_Global::config.load_script();
+    
+    return ok;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * resets the time
@@ -487,3 +570,35 @@ void U61_Game::pump_player_events()
     }
 } 
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the handler of the nth local player
+ * for instance, if players 1 & 3 are activated, asking for player
+ * 0 will return 1, player 1 will return 3 are 2 will return -1
+ * if no players are activated, player 0 is used
+ */
+int U61_Game::get_local_player(int order)
+{
+    int result=-1;
+    int found=0;
+    int i;
+
+    for (i=0;i<U61_Config::NB_PLAYERS;++i)
+    {
+        if (U61_Global::config.player[i].activable)
+        {
+            if (found==order)
+            {
+                result=i;
+            }
+            found++;
+        }
+    }
+    if (order==0 && result<0)
+    {
+        U61_Global::config.player[0].activable=true;
+        result=0;
+    }
+
+    return result;
+}
