@@ -90,22 +90,13 @@ void U61_Layout::reset()
  */
 void U61_Layout::init_alone(U61_Player *p)
 {
-    int i;
-    bool found=false;
-
     reset();
 
-    for (i=0;i<NB_PLAYERS_TOTAL && !found;++i)
-    {
-        if (p[i].is_available())
-        { 
-            found=true;
-            items[0].init(p+i,
-                          U61_Global::data.screen_w/2,
-                          U61_Global::data.screen_h/2,
-                          U61_Data::SIZE_BIG);
-        }
-    }
+    items[0].init(p,
+                  U61_Global::data.screen_w/2,
+                  U61_Global::data.screen_h/2,
+                  U61_Data::SIZE_BIG);
+    //cout<<"layout initialized with "<<p->get_name()<<"\n";
 }
 
 /*--------------------------------------------------------------------------*/
