@@ -172,6 +172,15 @@ char U61_Letter::operator =(char code)
     return code;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the ascii code of a letter
+ */
+int U61_Letter::get_ascii()
+{
+    return ascii;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * draws the letter onto a bitmap
