@@ -53,6 +53,25 @@
  globals
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/* 
+ * these arrays contain constants used for speeds, this way one can
+ * have something more subtle than just a linear behavior
+ */ 
+const int U61_Map::speeds[MAX_SYSTEM_SPEED+1]=
+    {
+       2,  5, 10, 20, 30, 35, 40, 45, 50, 55, 60,
+          65, 70, 75, 80, 85, 90, 95,100,105,110,
+         114,118,122,126,130,134,138,142,144,150,
+         153,156,159,162,165,168,171,174,177,180,
+         182,184,186,188,190,192,194,196,198,200
+    };
+const int U61_Map::accels[MAX_SYSTEM_ACCEL+1]=
+    {
+       0,  2,  5, 10, 15, 20,
+          30, 40, 60, 80,100,
+         120,140,160,180,200
+    };
 
 /*---------------------------------------------------------------------------
  functions
@@ -109,8 +128,9 @@ void U61_Map::begin()
     block.reset();
     block_requested=false;
     speed_counter=0;
-    speed=10000;
-    accel=10; 
+    accel_counter=0;
+    speed=base_speed;
+    accel=base_accel; 
     background=0;
     prevision_state=true;
     //block.shape(0);
@@ -120,13 +140,16 @@ void U61_Map::begin()
 /*
  * resets completely a map
  */
-void U61_Map::reset()
+void U61_Map::reset(int s,int a)
 {
-    begin();
     map_time=0;
     active=false;
     score=0;
     games=0; 
+    base_speed=s;
+    base_accel=a;
+
+    begin();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -147,7 +170,7 @@ bool U61_Map::is_active()
  */
 void U61_Map::set_active(int time)
 {
-    reset();
+    //reset();
     map_time=time;
     active=true;
 }
@@ -274,17 +297,24 @@ void U61_Map::compute_next()
  */
 void U61_Map::update_speed()
 {
-    speed+=accel;
-    speed_counter+=speed;
+    check_speed();
+    check_accel();
+
+    speed_counter+=speeds[speed];
     if (speed_counter>SPEED_SCALE)
     {
         speed_counter-=SPEED_SCALE;
         block_move_down(); 
     }    
-    if (speed_counter>SPEED_SCALE)
+    accel_counter+=accels[accel];
+    if (accel_counter>ACCEL_SCALE)
     {
-        speed_counter=0;
-    }
+        accel_counter-=ACCEL_SCALE;
+        speed++;
+    }    
+
+    check_speed();
+    check_accel();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -427,7 +457,7 @@ void U61_Map::put_auto_event(U61_Event event)
 /*
  * draws the map onto the screen
  */
-void U61_Map::draw(int x,int y, int size)
+void U61_Map::draw(int x,int y, int size, bool prev)
 {
     int i,j;
     int x_square_offset;
@@ -458,7 +488,7 @@ void U61_Map::draw(int x,int y, int size)
                                    size);
             }
         }
-        if (prevision_state)
+        if (prevision_state && prev)
         {
             draw_prevision(x_square_offset,y_square_offset,size);
         }
@@ -485,6 +515,76 @@ bool U61_Map::get_prevision_state()
     return prevision_state; 
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * sets the speed 
+ */
+void U61_Map::set_speed(int s)
+{
+    speed=s; 
+    check_speed();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the speed 
+ */
+int U61_Map::get_speed()
+{
+    return speed; 
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * checks if the speed is within the correct range
+ */
+void U61_Map::check_speed()
+{
+    if (speed>MAX_SYSTEM_SPEED)
+    {
+        speed=MAX_SYSTEM_SPEED;
+    }
+    if (speed<0)
+    {
+        speed=0;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * sets the accel
+ */
+void U61_Map::set_accel(int a)
+{
+    accel=a; 
+    check_accel();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the accel
+ */
+int U61_Map::get_accel()
+{
+    return accel; 
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * checks if the accel is within the correct range
+ */
+void U61_Map::check_accel()
+{
+    if (accel>MAX_SYSTEM_ACCEL)
+    {
+        accel=MAX_SYSTEM_ACCEL;
+    }
+    if (accel<0)
+    {
+        accel=0;
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * display the prevision, the prevision is "where the block will land if
@@ -504,6 +604,8 @@ void U61_Map::draw_prevision(int x,int y,int size)
             prev=test;
             test.move_down();
         }
+
+        U61_Script::block_land(this,&prev);
         prev.draw_prevision(x,y,size); 
     }
 }
@@ -664,6 +766,7 @@ void U61_Map::block_drop()
     }
 }
 
+
 /*--------------------------------------------------------------------------*/
 /*
  * checks if there's an active block (size greater than 0)
@@ -743,6 +846,7 @@ void U61_Map::stabilize_block()
     int x,y,i,n;
     bool outside=false;
 
+    U61_Script::block_land(this,&block);
     n=block.get_nb_items();
     for (i=0;i<n;++i)
     {
@@ -776,7 +880,7 @@ void U61_Map::stabilize_block()
  */
 void U61_Map::loose()
 {
-    cout<<"The game is lost\n";
+    //cout<<"The game is lost\n";
     begin();
 }
 
