@@ -43,6 +43,8 @@
 
 #include <ClanLib/core.h>
 
+#include "const.h"
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -53,10 +55,12 @@ public:
     U61_PlayerConfig();
     ~U61_PlayerConfig();
 
-    void reset();
-
     bool activable;
 
+    char name[U61_STRING_SIZE];
+
+    bool prevision;
+
     int key_start_stop;
     int key_move_left;
     int key_move_right;
@@ -67,7 +71,7 @@ public:
     int key_next_victim;
     int key_prev_victim;
     int key_use_antedote;
-
+  
     int first_repeat_move;
     int standard_repeat_move;
     int first_repeat_rotate;
@@ -76,6 +80,7 @@ public:
     int standard_repeat_other;
     
 protected:
+
 };
 
 #endif
