@@ -49,6 +49,7 @@
 #include <string.h>
 
 #include "script.h"
+#include "const.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -60,10 +61,26 @@
  * to act directly on a specified object
  * this way, when one writes lua code, one only has to assume that
  * functions always operate on the right block, the right map etc...
+ * they are not members of any class since they are used from
+ * standard C function
  */
 static U61_Block *current_block=NULL;
 static U61_Map *current_map=NULL;
 
+/*--------------------------------------------------------------------------*/
+/*
+ * the following booleans allows a full control of what exactly functions
+ * called from lua have the right to read/write
+ * for instance one may wish a function to be able to read the map state
+ * but bot overwrite it
+ * they are not members of any class since they are used from
+ * standard C function
+ */
+static bool block_read=false;
+static bool block_write=false;
+static bool map_read=false;
+static bool map_write=false;
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -168,6 +185,10 @@ void U61_Script::secure_pointers()
 {
     current_block=NULL;
     current_map=NULL;
+    block_read=false;
+    block_write=false;
+    map_read=false;
+    map_write=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -178,11 +199,13 @@ void U61_Script::secure_pointers()
 void U61_Script::block_shape(U61_Block *b, int type)
 {
     CL_LuaObject func;
-    char command[1000];
-    char arguments[1000];
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
 
     secure_pointers();
     current_block=b;
+    block_read=true;
+    block_write=true;
 
     //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
     //lua_callfunction(func);
@@ -202,11 +225,13 @@ void U61_Script::block_shape(U61_Block *b, int type)
 void U61_Script::block_rotate_right(U61_Block *b)
 {
     CL_LuaObject func;
-    char command[1000];
-    char arguments[1000];
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
 
     secure_pointers();
     current_block=b;
+    block_read=true;
+    block_write=true;
 
     //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
     //lua_callfunction(func);
@@ -226,11 +251,13 @@ void U61_Script::block_rotate_right(U61_Block *b)
 void U61_Script::block_rotate_left(U61_Block *b)
 {
     CL_LuaObject func;
-    char command[1000];
-    char arguments[1000];
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
 
     secure_pointers();
     current_block=b;
+    block_read=true;
+    block_write=true;
 
     //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
     //lua_callfunction(func);
@@ -250,11 +277,13 @@ void U61_Script::block_rotate_left(U61_Block *b)
 void U61_Script::block_move_right(U61_Block *b)
 {
     CL_LuaObject func;
-    char command[1000];
-    char arguments[1000];
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
 
     secure_pointers();
     current_block=b;
+    block_read=true;
+    block_write=true;
 
     //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
     //lua_callfunction(func);
@@ -274,11 +303,13 @@ void U61_Script::block_move_right(U61_Block *b)
 void U61_Script::block_move_left(U61_Block *b)
 {
     CL_LuaObject func;
-    char command[1000];
-    char arguments[1000];
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
 
     secure_pointers();
     current_block=b;
+    block_read=true;
+    block_write=true;
 
     //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
     //lua_callfunction(func);
@@ -298,11 +329,13 @@ void U61_Script::block_move_left(U61_Block *b)
 void U61_Script::block_move_down(U61_Block *b)
 {
     CL_LuaObject func;
-    char command[1000];
-    char arguments[1000];
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
 
     secure_pointers();
     current_block=b;
+    block_read=true;
+    block_write=true;
 
     //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
     //lua_callfunction(func);
@@ -313,6 +346,34 @@ void U61_Script::block_move_down(U61_Block *b)
     CL_Lua::dostring(command);
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * calls the user defined function which is meant to be call before
+ * the block is stabilized/included in the map
+ * the Lua function may leave the block unchanged
+ */
+void U61_Script::block_land(U61_Map *m,U61_Block *b)
+{
+    CL_LuaObject func;
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
+
+    secure_pointers();
+    current_block=b;
+    block_read=true;
+    block_write=true;
+    current_map=m;
+    map_read=true;
+
+    //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
+    //lua_callfunction(func);
+
+    sprintf(arguments,"()");
+    strcpy(command,LUA_BLOCK_LAND);
+    strcat(command,arguments);
+    CL_Lua::dostring(command);
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * calls the user defined function that finds patterns in a map
@@ -322,11 +383,13 @@ void U61_Script::block_move_down(U61_Block *b)
 void U61_Script::map_match_pattern(U61_Map *m)
 {
     CL_LuaObject func;
-    char command[1000];
-    char arguments[1000];
+    char command[U61_STRING_SIZE];
+    char arguments[U61_STRING_SIZE];
 
     secure_pointers();
     current_map=m;
+    map_read=true;
+    map_write=true;
 
     //func=CL_Lua::getglobal(LUA_NEW_BLOCK);
     //lua_callfunction(func);
@@ -344,7 +407,7 @@ void U61_Script::map_match_pattern(U61_Map *m)
  */
 static void block_reset()
 {
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_write)
     {
         current_block->reset();
     }
@@ -357,7 +420,7 @@ static void block_reset()
  */
 static void block_center()
 {
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_write)
     {
         current_block->center();
     }
@@ -372,7 +435,7 @@ static void block_get_x()
 {
     CL_LuaValue *x;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_read)
     {
         x=new CL_LuaValue(current_block->get_x());
         x->push();
@@ -389,7 +452,7 @@ static void block_get_y()
 {
     CL_LuaValue *y;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_read)
     {
         y=new CL_LuaValue(current_block->get_y());
         y->push();
@@ -406,7 +469,7 @@ static void block_set_x()
 {
     int x;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_write)
     {
         x=CL_Lua::getparam(1);
 
@@ -423,7 +486,7 @@ static void block_set_y()
 {
     int y;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_write)
     {
         y=CL_Lua::getparam(1);
 
@@ -440,7 +503,7 @@ static void block_add_item()
 {
     int type,x,y;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_write)
     {
         x=CL_Lua::getparam(1);        
         y=CL_Lua::getparam(2);        
@@ -459,7 +522,7 @@ static void block_get_nb_items()
 {
     CL_LuaValue *nb;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_read)
     {
         nb=new CL_LuaValue(current_block->get_nb_items());
         nb->push();
@@ -477,7 +540,7 @@ static void block_get_item_x()
     CL_LuaValue *x;
     int i;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_read)
     {
         i=CL_Lua::getparam(1);
 
@@ -497,7 +560,7 @@ static void block_get_item_y()
     CL_LuaValue *y;
     int i;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_read)
     {
         i=CL_Lua::getparam(1);
 
@@ -517,7 +580,7 @@ static void block_get_item_color()
     CL_LuaValue *color;
     int i;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_read)
     {
         i=CL_Lua::getparam(1);
 
@@ -536,7 +599,7 @@ static void block_set_item_x()
 {
     int i,x;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_write)
     {
         i=CL_Lua::getparam(1);
         x=CL_Lua::getparam(2);
@@ -554,7 +617,7 @@ static void block_set_item_y()
 {
     int i,y;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_write)
     {
         i=CL_Lua::getparam(1);
         y=CL_Lua::getparam(2);
@@ -572,7 +635,7 @@ static void block_set_item_color()
 {
     int i,color;
 
-    if (current_block!=NULL)
+    if (current_block!=NULL && block_write)
     {
         i=CL_Lua::getparam(1);
         color=CL_Lua::getparam(2);
@@ -590,7 +653,7 @@ static void map_get_width()
 {
     CL_LuaValue *width;
 
-    if (current_map!=NULL)
+    if (current_map!=NULL && map_read)
     {
         width=new CL_LuaValue(U61_Map::WIDTH);
         width->push();
@@ -607,7 +670,7 @@ static void map_get_height()
 {
     CL_LuaValue *height;
 
-    if (current_map!=NULL)
+    if (current_map!=NULL && map_read)
     {
         height=new CL_LuaValue(U61_Map::HEIGHT);
         height->push();
@@ -625,7 +688,7 @@ static void map_get_square_color()
     int x,y;
     CL_LuaValue *color;
 
-    if (current_map!=NULL)
+    if (current_map!=NULL && map_read)
     {
         x=CL_Lua::getparam(1);
         y=CL_Lua::getparam(2);
@@ -645,7 +708,7 @@ static void map_set_square_color()
 {
     int x,y,color;
 
-    if (current_map!=NULL)
+    if (current_map!=NULL && map_write)
     {
         x=CL_Lua::getparam(1);
         y=CL_Lua::getparam(2);
@@ -664,7 +727,7 @@ static void map_get_score()
 {
     CL_LuaValue *score;
 
-    if (current_map!=NULL)
+    if (current_map!=NULL && map_read)
     {
         score=new CL_LuaValue(current_map->get_score());
         score->push();
@@ -681,7 +744,7 @@ static void map_set_score()
 {
     int score;
 
-    if (current_map!=NULL)
+    if (current_map!=NULL && map_write)
     {
         score=CL_Lua::getparam(1);
 
