@@ -72,6 +72,7 @@ public:
     static void block_move_left(U61_Block *b);
     static void block_move_right(U61_Block *b);
     static void block_move_down(U61_Block *b);
+    static void block_land(U61_Map *m,U61_Block *b);
     static void map_match_pattern(U61_Map *m);
 
     static char *const LUA_BLOCK_SHAPE="user_block_shape";
@@ -80,6 +81,7 @@ public:
     static char *const LUA_BLOCK_MOVE_LEFT="user_block_move_left";
     static char *const LUA_BLOCK_MOVE_RIGHT="user_block_move_right";
     static char *const LUA_BLOCK_MOVE_DOWN="user_block_move_down";
+    static char *const LUA_BLOCK_LAND="user_block_land";
     static char *const LUA_MAP_MATCH_PATTERN="user_map_match_pattern";
 
     static char *const C_BLOCK_RESET="u61_block_reset";
